==> seewave_1.5.9.zip: seewave/doc/seewave_IO.R <==
###################################################
### chunk number 1: s1
###################################################
s1<-sin(2*pi*440*seq(0,1,length.out=8000))
is.vector(s1)
mode(s1)
library(seewave)
oscillo(s1,f=8000)


###################################################
### chunk number 2: s2
###################################################
s2<-as.matrix(s1)
is.matrix(s2)
dim(s2)
oscillo(s2,f=8000)


###################################################
### chunk number 3: s3
###################################################
x<-rnorm(8000)
s3<-cbind(s2,x)
is.matrix(s3)
dim(s3)
oscillo(s3,f=8000)


###################################################
### chunk number 4: s4a
###################################################
s4<-ts(data=s1, start=0, frequency=8000)
str(s4)


###################################################
### chunk number 5: s4b
###################################################
s4<-ts(data=runif(4000), start=0, end=0.5, frequency=8000)
str(s4)


###################################################
### chunk number 6: s4c
###################################################
frequency(s4)
deltat(s4)


###################################################
### chunk number 7: s4d
###################################################
oscillo(s4)


###################################################
### chunk number 8: s5
###################################################
s5<-ts(data=s3,f=8000)
class(s5)
oscillo(s5)


###################################################
### chunk number 9: readWave
###################################################
library(tuneR)
mysong<-synth(d=60,f=8000,cf=1000,output="Wave")
savewav(mysong)


###################################################
### chunk number 10: s6
###################################################
s6<-readWave("mysong.wav")
s6


###################################################
### chunk number 11: s7a
###################################################
s7<-readWave("mysong.wav", from = 1, to = 5, units = "seconds")
s7


###################################################
### chunk number 12: s7b
###################################################
s7@samp.rate
s7@bit
s7@stereo


###################################################
### chunk number 13: rangereadWave
###################################################
range(s7@left)


###################################################
### chunk number 14: 
###################################################
detach(package: tuneR)
library(sound)


###################################################
### chunk number 15: s8a
###################################################
s8<-loadSample("mysong.wav")
s8


###################################################
### chunk number 16: s8b
###################################################
rate(s8)
s8$rate
duration(s8)
s8$duration


###################################################
### chunk number 17: rangeSample
###################################################
range(s8$sound[1,])


###################################################
### chunk number 18: s9
###################################################
s9<-repw(s2,f=8000,times=2,output="Sample")
s9


###################################################
### chunk number 19: 
###################################################
f<-8000
oscillo(s2,f)


###################################################
### chunk number 20: 
###################################################
detach(package: sound)
library(audio)


###################################################
### chunk number 21: s10
###################################################
s10<-load.wave("mysong.wav")
head(s10)
s10$rate
s10$bits


###################################################
### chunk number 22: s11 eval=FALSE
###################################################
## s11 <- rep(NA_real_, 16000*5)
## record(s11, 16000, 1)


###################################################
### chunk number 23: 
###################################################
detach(package: audio)
library(tuneR)


###################################################
### chunk number 24: exporta
###################################################
data(tico)
export(tico, f=22050, header=FALSE)


###################################################
### chunk number 25: exportb
###################################################
export(tico, f=22050, filename="tico_Gold.txt")


###################################################
### chunk number 26: exportc
###################################################
export(tico, f=22050, filename="tico_ext.txt",
header="f=22050; ch=left")


###################################################
### chunk number 27: savewave
###################################################
savewav(tico, f=22050)


###################################################
### chunk number 28: savewavb
###################################################
ticofirst<-cutw(tico, f=22050, to=0.5, output="Wave")
savewav(ticofirst, filename = "tico_firstnote.wav")


###################################################
### chunk number 29: s12
###################################################
left<-sine(440, bit = 16)
right<-sine(2000, bit = 16)
s12<-stereo(left,right)
s12


###################################################
### chunk number 30: s13
###################################################
s13<-mono(s12,"left")


###################################################
### chunk number 31: 
###################################################
s14<-channel(s12,"right")


###################################################
### chunk number 32: s14
###################################################
s13<-s12@left
is.vector(s13)
s14<-s12@right
is.vector(s14)


###################################################
### chunk number 33: 
###################################################
detach(package: tuneR)
library(sound)


###################################################
### chunk number 34: 
###################################################
left<-synth(cf=440,d=5,f=8000,output="Sample")
right<-synth(cf=2000,d=5,f=8000,output="Sample")
s13<-stereo(left,right)
s13


###################################################
### chunk number 35: 
###################################################
s14<-left(s13)
s14
s15<-right(s13)
s15


###################################################
### chunk number 36: 
###################################################
s16<-s13$sound[1, ]
is.vector(s16)
s17<-s13$sound[2, ]
is.vector(s17)


###################################################
### chunk number 37: 
###################################################
s13<-mirror(s13)
s14<-panorama(s13, pan=30)

==> seewave_1.6.1.zip: seewave/doc/seewave_IO.R <==
### R code from vignette source 'seewave_IO.rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: s1
###################################################
s1<-sin(2*pi*440*seq(0,1,length.out=8000))
is.vector(s1)
mode(s1)
library(seewave)
oscillo(s1,f=8000)


###################################################
### code chunk number 2: s2
###################################################
s2<-as.matrix(s1)
is.matrix(s2)
dim(s2)
oscillo(s2,f=8000)


###################################################
### code chunk number 3: s3
###################################################
x<-rnorm(8000)
s3<-cbind(s2,x)
is.matrix(s3)
dim(s3)
oscillo(s3,f=8000)


###################################################
### code chunk number 4: s4a
###################################################
s4<-ts(data=s1, start=0, frequency=8000)
str(s4)


###################################################
### code chunk number 5: s4b
###################################################
s4<-ts(data=runif(4000), start=0, end=0.5, frequency=8000)
str(s4)


###################################################
### code chunk number 6: s4c
###################################################
frequency(s4)
deltat(s4)


###################################################
### code chunk number 7: s4d
###################################################
oscillo(s4)


###################################################
### code chunk number 8: s5
###################################################
s5<-ts(data=s3,f=8000)
class(s5)
oscillo(s5)


###################################################
### code chunk number 9: readWave
###################################################
library(tuneR)
mysong<-synth(d=60,f=8000,cf=1000,output="Wave")
savewav(mysong)


###################################################
### code chunk number 10: s6
###################################################
s6<-readWave("mysong.wav")
s6


###################################################
### code chunk number 11: s7a
###################################################
s7<-readWave("mysong.wav", from = 1, to = 5, units = "seconds")
s7


###################################################
### code chunk number 12: s7b
###################################################
s7@samp.rate
s7@bit
s7@stereo


###################################################
### code chunk number 13: rangereadWave
###################################################
range(s7@left)


###################################################
### code chunk number 14: seewave_IO.rnw:167-169
###################################################
detach(package: tuneR)
library(sound)


###################################################
### code chunk number 15: s8a
###################################################
s8<-loadSample("mysong.wav")
s8


###################################################
### code chunk number 16: s8b
###################################################
rate(s8)
s8$rate
duration(s8)
s8$duration


###################################################
### code chunk number 17: rangeSample
###################################################
range(s8$sound[1,])


###################################################
### code chunk number 18: s9
###################################################
s9<-repw(s2,f=8000,times=2,output="Sample")
s9


###################################################
### code chunk number 19: seewave_IO.rnw:196-198
###################################################
f<-8000
oscillo(s2,f)


###################################################
### code chunk number 20: seewave_IO.rnw:203-205
###################################################
detach(package: sound)
library(audio)


###################################################
### code chunk number 21: s10
###################################################
s10<-load.wave("mysong.wav")
head(s10)
s10$rate
s10$bits


###################################################
### code chunk number 22: s11 (eval = FALSE)
###################################################
## s11 <- rep(NA_real_, 16000*5)
## record(s11, 16000, 1)


###################################################
### code chunk number 23: seewave_IO.rnw:221-223
###################################################
detach(package: audio)
library(tuneR)


###################################################
### code chunk number 24: exporta
###################################################
data(tico)
export(tico, f=22050, header=FALSE)


###################################################
### code chunk number 25: exportb
###################################################
export(tico, f=22050, filename="tico_Gold.txt")


###################################################
### code chunk number 26: exportc
###################################################
export(tico, f=22050, filename="tico_ext.txt",
header="f=22050; ch=left")


###################################################
### code chunk number 27: savewave
###################################################
savewav(tico, f=22050)


###################################################
### code chunk number 28: savewavb
###################################################
ticofirst<-cutw(tico, f=22050, to=0.5, output="Wave")
savewav(ticofirst, filename = "tico_firstnote.wav")


###################################################
### code chunk number 29: s12
###################################################
left<-sine(440, bit = 16)
right<-sine(2000, bit = 16)
s12<-stereo(left,right)
s12


###################################################
### code chunk number 30: s13
###################################################
s13<-mono(s12,"left")


###################################################
### code chunk number 31: seewave_IO.rnw:293-294
###################################################
s14<-channel(s12,"right")


###################################################
### code chunk number 32: s14
###################################################
s13<-s12@left
is.vector(s13)
s14<-s12@right
is.vector(s14)


###################################################
### code chunk number 33: seewave_IO.rnw:305-307
###################################################
detach(package: tuneR)
library(sound)


###################################################
### code chunk number 34: seewave_IO.rnw:311-315
###################################################
left<-synth(cf=440,d=5,f=8000,output="Sample")
right<-synth(cf=2000,d=5,f=8000,output="Sample")
s13<-stereo(left,right)
s13


###################################################
### code chunk number 35: seewave_IO.rnw:318-322
###################################################
s14<-left(s13)
s14
s15<-right(s13)
s15


###################################################
### code chunk number 36: seewave_IO.rnw:325-329
###################################################
s16<-s13$sound[1, ]
is.vector(s16)
s17<-s13$sound[2, ]
is.vector(s17)


###################################################
### code chunk number 37: seewave_IO.rnw:332-334
###################################################
s13<-mirror(s13)
s14<-panorama(s13, pan=30)
